@@ -25,8 +25,8 @@ class Droplet(object):
         payload.update(params)
         r = requests.get("https://api.digitalocean.com/droplets/%s%s" % ( self.id, path ), params=payload)
         data = r.json()
+        self.call_response = data
         if data['status'] != "OK":
-            self.call_response = data
             raise Exception(data[u'error_message'])
         #add the event to the object's event list.
         event_id = data.get(u'event_id',None)
@@ -127,7 +127,7 @@ class Droplet(object):
         """
         self.__call_api("/destroy/")
 
-    def create(self):
+    def create(self, ssh_key_ids=None, virtio=False):
         """
             Create the droplet with object properties.
         """
@@ -137,6 +137,10 @@ class Droplet(object):
                 "image_id": self.image_id,
                 "region_id": self.region_id
             }
+        if ssh_key_ids:
+            data['ssh_key_ids'] = ','.join(ssh_key_ids)
+        if virtio:
+            data['virtio'] = 1
         data = self.__call_api("new", data)
         if data:
             self.id = data['droplet']['id']
