@@ -1,7 +1,7 @@
 
 """digitalocean API to manage droplets"""
 
-__version__ = "0.2.7"
+__version__ = "0.2.9"
 __author__ = "Lorenzo Setale ( http://who.is.koalalorenzo.com/? )"
 __author_email__ = "koalalorenzo@gmail.com"
 __license__ = "See: http://creativecommons.org/licenses/by-nd/3.0/ "
@@ -13,3 +13,5 @@ from .Region import Region
 from .Size import Size
 from .Image import Image
 from .Event import Event
+from .Domain import Domain
+from .Record import Record
